scilpy.tractograms package
==========================


scilpy.tractograms.dps\_and\_dpp\_management module
-------------------------------------------------------

.. automodule:: scilpy.tractograms.dps_and_dpp_management
   :members:
   :undoc-members:
   :show-inheritance:

scilpy.tractograms.lazy\_tractogram\_operations module
-------------------------------------------------------

.. automodule:: scilpy.tractograms.lazy_tractogram_operations
   :members:
   :undoc-members:
   :show-inheritance:

scilpy.tractograms.streamline\_and\_mask\_operations module
------------------------------------------------------------

.. automodule:: scilpy.tractograms.streamline_and_mask_operations
   :members:
   :undoc-members:
   :show-inheritance:

scilpy.tractograms.tractogram\_operations module
------------------------------------------------------

.. automodule:: scilpy.tractograms.tractogram_operations
   :members:
   :undoc-members:
   :show-inheritance:

scilpy.tractograms.uncompress module
------------------------------------------------------

.. automodule:: scilpy.tractograms.uncompress
   :members:
   :undoc-members:
   :show-inheritance: